@@ -11,7 +11,7 @@ function(para) {
               L3   = NULL,
               L4   = NULL,
               L5   = NULL,
-              source = "lmomglo--ordinary"
+              source = "lmomglo"
              )
     # fifth L-moment is not given by Hosking and Wallis (1997)
     #  SMALL IS USED TO DECIDE WHETHER TO APPROXIMATE THE FIRST 2 
